@@ -22,13 +22,13 @@
 #'
 #' @export
 
-rmExcept <- function(keepers, envir = globalenv(), message = TRUE){
-    if (class(keepers) != 'character'){
+rmExcept <- function(keepers, envir = globalenv(), message = TRUE) {
+    if (class(keepers) != 'character') {
         stop('The keepers argument must be a character vector.', call. = FALSE)
     }
     DeleteObj <- setdiff(ls(envir = envir), keepers)
     rm(list = DeleteObj, envir = envir)
-    if (isTRUE(message)){
+    if (isTRUE(message)) {
         message("Removed the following objects:\n")
         message(paste(DeleteObj, collapse = ", "))
     }
@@ -44,8 +44,7 @@ rmExcept <- function(keepers, envir = globalenv(), message = TRUE){
 #' found in.
 #' @param keep.found logical. whether or not to keep observations where the
 #' pattern is found (\code{TRUE}) or not found (\code{FALSE}).
-#' @param useBytes logical. If TRUE the matching is done byte-by-byte rather
-#' than character-by-character. See \code{\link{grep}}.
+#' @param ... arguments to pass to \code{\link{grepl}}.
 #'
 #' @examples
 #' # Create data frame
@@ -58,12 +57,12 @@ rmExcept <- function(keepers, envir = globalenv(), message = TRUE){
 #'
 #' @export
 
-grepl.sub <- function(data, pattern, Var, keep.found = TRUE, useBytes = TRUE){
+grepl.sub <- function(data, pattern, Var, keep.found = TRUE, ...){
     y <- NULL
     if (missing(Var)) stop('Var must be specified', call. = FALSE)
 
-    data$y <- grepl(pattern = paste0(pattern, collapse="|"), x = data[, Var],
-                  useBytes = useBytes)
+    data$y <- grepl(pattern = paste0(pattern, collapse =  "|"), x = data[, Var],
+                    ...)
     subdata <- subset(data, y == keep.found)
     subdata$y <- NULL
     subdata
@@ -112,27 +111,27 @@ grepl.sub <- function(data, pattern, Var, keep.found = TRUE, useBytes = TRUE){
 
 FindReplace <- function(data, Var, replaceData, from = 'from', to = 'to',
                         exact = TRUE, vector = FALSE){
-  if(!(class(data[, Var]) %in% c('character', 'factor'))){
+  if (!(class(data[, Var]) %in% c('character', 'factor'))) {
     stop(paste(Var, 'is not a character string or factor. Please convert to a character string or factor and then rerun.'),
          call. = FALSE)
   }
-  if (isTRUE(exact)){
+  if (isTRUE(exact)) {
     message('Only exact matches will be replaced.')
   }
 
   ReplaceNRows <- nrow(replaceData)
 
-  for (i in 1:ReplaceNRows){
-    if(isTRUE(exact)){
+  for (i in 1:ReplaceNRows) {
+    if (isTRUE(exact)) {
       data[, Var] <- gsub(pattern = paste0("^", replaceData[i, from], "$"),
                         replacement = replaceData[i, to], data[, Var])
     }
-    if(!isTRUE(exact)){
+    if (!isTRUE(exact)) {
       data[, Var] <- gsub(pattern = replaceData[i, from],
                         replacement = replaceData[i, to], data[, Var])
     }
   }
-  if(isTRUE(vector)){
+  if (isTRUE(vector)) {
     data <- data[, Var]
   }
   return(data)
@@ -158,8 +157,8 @@ FindReplace <- function(data, Var, replaceData, from = 'from', to = 'to',
 #'
 #' @export
 
-VarDrop <- function(data, Var){
-    if (!all(Var %in% names(data))){
+VarDrop <- function(data, Var) {
+    if (!all(Var %in% names(data))) {
     message('At least one of the specified variables to drop is not found.')
     }
     data <- data[, !(names(data) %in% Var)]
@@ -204,7 +203,7 @@ dMerge <- function(data1, data2, Var, dropDups = TRUE, dupsOut = FALSE,
     fromLast = FALSE, all = FALSE, all.x = all, all.y = all,
     sort = TRUE, suffixes = c(".x",".y"),
     incomparables = NULL){
-    if (isTRUE(dropDups) & isTRUE(dupsOut)){
+    if (isTRUE(dropDups) & isTRUE(dupsOut)) {
         message("dropDups ignored")
         dropDups <- FALSE
     }
@@ -219,22 +218,22 @@ dMerge <- function(data1, data2, Var, dropDups = TRUE, dupsOut = FALSE,
     DupDF <- Comb[duplicated(Comb[, Var]), ]
 
     # Inform user of duplicates and drop if requested
-    if (is.null(DupDF)){
+    if (is.null(DupDF)) {
         message('There are no duplicated rows.')
-        if (isTRUE(dupsOut)){
+        if (isTRUE(dupsOut)) {
             message('Full data set returned.')
         }
     }
-    else if (!is.null(DupDF)){
+    else if (!is.null(DupDF)) {
         Count <- nrow(DupDF)
-        if (!isTRUE(dropDups) & !isTRUE(dupsOut)){
+        if (!isTRUE(dropDups) & !isTRUE(dupsOut)) {
             message(paste('There are', Count, 'duplicated rows.'))
         }
-        else if (isTRUE(dropDups) & !isTRUE(dupsOut)){
+        else if (isTRUE(dropDups) & !isTRUE(dupsOut)) {
             Comb <- Comb[!duplicated(Comb[, Var], fromLast = fromLast), ]
             message(paste(Count, 'duplicated rows were dropped.'))
         }
-    else if (!isTRUE(dropDups) & isTRUE(dupsOut)){
+    else if (!isTRUE(dropDups) & isTRUE(dupsOut)) {
         message(paste('There are', Count, 'duplicated rows.'))
         Comb <- DupDF
         }
@@ -266,16 +265,54 @@ dMerge <- function(data1, data2, Var, dropDups = TRUE, dupsOut = FALSE,
 #' @export
 
 InsertRow <- function(data, NewRow, RowNum = NULL) {
-  if (ncol(data) != length(NewRow)){
-    stop('NewRow must be the same length as the number of columns in the data.\n',
-         call. = FALSE)
-  }
-  if (!is.null(RowNum)){
-    data[seq(RowNum + 1,nrow(data) + 1), ] <- data[seq(RowNum, nrow(data)), ]
-    data[RowNum, ] <- NewRow
-  }
-  else if (is.null(RowNum)){
-    data <- rbind(data, NewRow)
-  }
-  return(data)
+    if (ncol(data) != length(NewRow)) {
+        stop('NewRow must be the same length as the number of columns in the data.\n',
+             call. = FALSE)
+    }
+    if (!is.null(RowNum)) {
+        data[seq(RowNum + 1,nrow(data) + 1), ] <- data[seq(RowNum, nrow(data)), ]
+        data[RowNum, ] <- NewRow
+    }
+    else if (is.null(RowNum)) {
+        data <- rbind(data, NewRow)
+    }
+    return(data)
+}
+
+#' Find duplicated values in a data frame and subset it to either include or
+#' not include them.
+#'
+#' @param data a data frame to select the duplicated values from.
+#' @param Vars character vector of variables in \code{data} to find duplicated
+#' values on.
+#' @param NotDups logical. If \code{TRUE} then a data frame without duplicated
+#' values is returned.
+#' @param test logical. If \code{TRUE} then the function will return an error
+#' if there are duplicated values.
+#' @param ... arguments to pass to \code{\link{duplicated}}.
+#'
+#' @examples
+#' Data <- data.frame(ID = c(1, 1, 2, 2), Value = c(1, 2, 3, 4))
+#' 
+#' FindDups(Data, Vars = 'ID')
+#'
+#' @return a data frame, unless \code{test = TRUE} and there are duplicates.
+#'
+#' @export
+
+FindDups <- function(data, Vars, NotDups = FALSE, test = FALSE, ...) {
+    dups <- data[duplicated(data[, Vars], ...), ]
+    numb_dups <- nrow(dups)
+    message(sprintf('%s duplicates in the data frame.', numb_dups))
+
+    if (isTRUE(test) & numb_dups != 0) stop('Find your duplicates!', call. = F)
+
+    if (!isTRUE(NotDups)) {
+        if (numb_dups > 0) {
+            out <- dups[, Vars]
+        }
+    } 
+    if (isTRUE(NotDups)) out <- data[!duplicated(data[, Vars], ...), ]
+
+    if (!isTRUE(test) & numb_dups > 0) return(out)
 }
